@@ -325,10 +325,10 @@
 
 
 #==========================    Modified Code    ======================================
+import os
 import random
 import dateutil.parser
 from datetime import datetime
-import logging
 
 from openpyxl import Workbook
 from openpyxl.styles import PatternFill, Font, Alignment
@@ -342,11 +342,10 @@ from openpyxl.chart import (
     Series,
 )
 from openpyxl.chart.series import DataPoint
-
+app_name = os.getenv("PLATFORM_ROUTE")
 
 class ExcelRenderer:
     ROW_START = 3
-    logging.error(f'{ROW_START} <-----   Enter Into Excel Process   ----->')
     def __init__(self, analysis_run):
         """
         :param analysis_run: AnalysisRun
@@ -502,7 +501,7 @@ class ExcelRenderer:
 
         ws.merge_cells('B3:Z4')
         cell = ws['B3']
-        cell.value = "asset-insights"
+        cell.value = app_name
         cell.font = Font(color="00598B", bold=True)
         cell.alignment = Alignment(vertical="center")
         cell.fill = PatternFill("solid", fgColor="eeeeee")
@@ -513,7 +512,7 @@ class ExcelRenderer:
         cell.fill = PatternFill("solid", fgColor="eeeeee")
 
         cell = ws['B6']
-        cell.value = 'Client'
+        cell.value = 'Tenant'
         cell.alignment = Alignment(horizontal="right")
         cell.font = Font(color="00598B")
         cell.fill = PatternFill("solid", fgColor="eeeeee")
@@ -608,7 +607,7 @@ class ExcelRenderer:
 
         ws.merge_cells('B1:Z2')
         cell = ws['B1']
-        cell.value = "Asset-Insights"
+        cell.value = app_name.title()
         cell.font = Font(color="00598B", bold=True)
         cell.fill = PatternFill("solid", fgColor="eeeeee")
         cell.alignment = Alignment(vertical="center")
@@ -627,6 +626,9 @@ class ExcelRenderer:
             if component_data.get('title'):
                 self.add_component_title(ws, component_data)
             self.add_table(ws, component_data)
+        elif component_data['type'] == 'name':
+            if component_data.get('title'):
+                self.add_component_title(ws, component_data)
         elif component_data['type'] == 'doughnut-chart':
             self.add_doughnut_chart(ws, component_data)
         elif component_data['type'] == 'bar-chart':
