@@ -1,5 +1,6 @@
 import os
 import time
+import datetime
 import logging
 from io import BytesIO
 from datetime import datetime
@@ -29,7 +30,7 @@ API_RETRY = int(os.getenv('API_RETRY', 3))
 API_KEY = os.getenv('API_KEY')
 API_SECRET = os.getenv('API_SECRET')
 BASE_API_URL = os.getenv('DATA_API_BASE_URL', '')
-ROUTE = os.getenv("PLATFORM_ROUTE")
+PLATFORM_ROUTE = os.getenv("PLATFORM_ROUTE")
 
 storage_name = os.getenv('STORAGE_NAME')
 
@@ -166,7 +167,7 @@ def get_run_result(run_id, field=None, default_value=None):
 def get_result_by_run(run_id, field=None, default_value=None):
     try:
         s3 = get_s3_client()
-        run_id= f'analytics-apps/{ROUTE}/json/{run_id}'
+        run_id= f'analytics-apps/{PLATFORM_ROUTE}/json/{run_id}'
         res_object = s3.get_object(Bucket=BUCKET_NAME,Key=run_id)
         serializedObject = res_object['Body'].read()
         result = json.loads(serializedObject)
@@ -252,7 +253,7 @@ def generate_pdf(analysis_run):
     # analysis_run = json.dumps(analysis_run)
     data = {
         'domain': BASE_API_URL,
-        'report': ROUTE,
+        'report': PLATFORM_ROUTE,
         'run': analysis_run,
         'route': '/full-view',
         'token': get_token(),
@@ -282,6 +283,62 @@ def generate_excel(analysis_run, file_name=None):
     return output
 
 
+def update_db_url(response, analysisRunId):
+        result_path=f'analytics-apps/{PLATFORM_ROUTE}/json/'
+        location=result_path + analysisRunId
+        result_url = upload_to_s3(json.dumps(response).encode(), location)
+        logger.info('Compute results url is %s', result_url)
+        url = BASE_API_URL + f'/api/v2/tenants/client_53/resources/{analysisRunId}'
+        data={ 
+                "description" : result_url
+             }
+        
+        res = call_post_requests(url , data=json.dumps(data), verify=False);
+        logger.info('Database update response is %s', res)
+
+
+#Upload excel file to s3
+def upload_excel_s3(local_file, bucket, s3_file):
+    s3 = get_s3_client()
+    try:
+        s3.upload_file(local_file, bucket, s3_file)
+        url = f'https://{bucket}.s3.{REGION_NAME}.amazonaws.com/{s3_file}'
+        logger.info('Upload successful, result url is %s', url)
+        return True
+    except FileNotFoundError:
+        logger.info('File was not found')
+        return False
+    except NoCredentialsError:
+        logger.info('Invalid credentials')
+        return False
+
+
+#Delete excel_file from local path
+def delete_excel_file(source_path):
+    try:
+        os.remove(source_path)
+        logger.info('Excel file successfully deleted')
+    except OSError as e:
+        logger.info(f'Failed to delete: %s : %s % {file_path, e.strerror}')
+
+
+
+#Generate excel file
+def generate_excel_file(run_id):
+    import time
+    import datetime
+    logger.info('Entered into excel generation process')
+    excel_data=get_result_by_run(run_id, 'excel-data', {})
+    reportname = 'asset-insights' + '-' + datetime.datetime.now().strftime('%Y-%m-%d-%I-%M-%S') + '.xlsx'
+    filepath = './' + reportname
+    generate_excel(excel_data, filepath)
+    excel_file_location = f'analytics-apps/{PLATFORM_ROUTE}/excel/' + reportname
+    
+    upload_excel_s3(filepath, BUCKET_NAME, excel_file_location)
+    
+    #delete_excel_file(filepath)
+
+
 def upload_excel(analysis_run, excel_file):
     timestamp = datetime.now().strftime("%Y-%m-%d-%H-%M-%S")
     s3_path = f'{analysis_run.analysis.app.slug}/excel/{timestamp}.xlsx'
